@@ -54,6 +54,13 @@
  * and the g_irepository_prepend_search_path() calls.
  */
 
+/* The namespace and version corresponding to libgirepository itself, so
+ * that we can refuse to load typelibs corresponding to the newer,
+ * incompatible version of this same library in GLib. */
+#define GIREPOSITORY_TYPELIB_NAME "GIRepository"
+#define GIREPOSITORY_TYPELIB_VERSION "2.0"
+#define GIREPOSITORY_TYPELIB_FILENAME \
+  GIREPOSITORY_TYPELIB_NAME "-" GIREPOSITORY_TYPELIB_VERSION ".typelib"
 
 static GIRepository *default_repository = NULL;
 static GSList *typelib_search_path = NULL;
@@ -455,7 +462,7 @@ register_internal (GIRepository *repository,
  * @namespace_: Namespace of interest
  *
  * Return an array of the immediate versioned dependencies for @namespace_.
- * Returned strings are of the form <code>namespace-version</code>.
+ * Returned strings are of the form `namespace-version`.
  *
  * Note: @namespace_ must have already been loaded using a function
  * such as g_irepository_require() before calling this function.
@@ -537,9 +544,10 @@ get_typelib_dependencies_transitive (GIRepository *repository,
  *   process-global default #GIRepository
  * @namespace_: Namespace of interest
  *
- * Return an array of all (transitive) versioned dependencies for
- * @namespace_. Returned strings are of the form
- * <code>namespace-version</code>.
+ * Retrieves all (transitive) versioned dependencies for
+ * @namespace_.
+ *
+ * The strings are of the form `namespace-version`.
  *
  * Note: @namespace_ must have already been loaded using a function
  * such as g_irepository_require() before calling this function.
@@ -547,7 +555,7 @@ get_typelib_dependencies_transitive (GIRepository *repository,
  * To get only the immediate dependencies for @namespace_, use
  * g_irepository_get_immediate_dependencies().
  *
- * Returns: (transfer full): Zero-terminated string array of all versioned
+ * Returns: (transfer full) (array zero-terminated=1): all versioned
  *   dependencies
  */
 char **
@@ -806,12 +814,14 @@ find_by_gtype (GHashTable *table, FindByGTypeData *data, gboolean check_prefix)
  */
 GIBaseInfo *
 g_irepository_find_by_gtype (GIRepository *repository,
-			     GType         gtype)
+                             GType         gtype)
 {
   FindByGTypeData data;
   GIBaseInfo *cached;
   DirEntry *entry;
 
+  g_return_val_if_fail (gtype != G_TYPE_INVALID, NULL);
+
   repository = get_repository (repository);
 
   cached = g_hash_table_lookup (repository->priv->info_by_gtype,
@@ -1252,6 +1262,16 @@ find_namespace_version (const gchar  *namespace,
   GMappedFile *mfile = NULL;
   char *fname;
 
+  if (g_str_equal (namespace, GIREPOSITORY_TYPELIB_NAME) &&
+      !g_str_equal (version, GIREPOSITORY_TYPELIB_VERSION))
+    {
+      g_debug ("Ignoring %s-%s.typelib because this libgirepository "
+              "corresponds to %s-%s",
+               namespace, version,
+               namespace, GIREPOSITORY_TYPELIB_VERSION);
+      return NULL;
+    }
+
   fname = g_strdup_printf ("%s-%s.typelib", namespace, version);
 
   for (ldir = search_path; ldir; ldir = ldir->next)
@@ -1403,6 +1423,15 @@ enumerate_namespace_versions (const gchar *namespace,
 	      const char *name_end;
 	      int major, minor;
 
+	     if (g_str_equal (namespace, GIREPOSITORY_TYPELIB_NAME) &&
+		 !g_str_equal (entry, GIREPOSITORY_TYPELIB_FILENAME))
+	       {
+		 g_debug ("Ignoring %s because this libgirepository "
+			  "corresponds to %s",
+			  entry, GIREPOSITORY_TYPELIB_FILENAME);
+		 continue;
+	       }
+
 	      name_end = strrchr (entry, '.');
 	      last_dash = strrchr (entry, '-');
 	      version = g_strndup (last_dash+1, name_end-(last_dash+1));
