@@ -10,6 +10,7 @@
 #include <time.h>
 #include <string.h>
 #include <stdlib.h>
+#include <sys/types.h>
 
 #include "gitestmacros.h"
 
@@ -93,6 +94,9 @@ gunichar regress_test_unichar (gunichar in);
 _GI_TEST_EXTERN
 time_t regress_test_timet (time_t in);
 
+_GI_TEST_EXTERN
+off_t regress_test_offt (off_t in);
+
 _GI_TEST_EXTERN
 GType regress_test_gtype (GType in);
 
@@ -1274,6 +1278,15 @@ RegressTestObj *regress_test_obj_new_callback (RegressTestCallbackUserData callb
                                 gpointer user_data,
                                 GDestroyNotify notify);
 
+_GI_TEST_EXTERN
+void regress_test_obj_new_async (const char          *x G_GNUC_UNUSED,
+                                 GCancellable        *cancellable G_GNUC_UNUSED,
+                                 GAsyncReadyCallback  callback G_GNUC_UNUSED,
+                                 gpointer             user_data G_GNUC_UNUSED);
+_GI_TEST_EXTERN
+RegressTestObj *regress_test_obj_new_finish (GAsyncResult  *res G_GNUC_UNUSED,
+                                             GError       **error G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void regress_test_hash_table_callback (GHashTable *data, RegressTestCallbackHashtable callback);
 
